@@ -623,13 +623,14 @@ void add_interval_to_specification(nfer_specification *spec, interval *add, pool
                 }
             }
 
-            // before testing minimality, if a window is used, remove anything from the produced pool that is too old
-            if (opt_window_size != NO_WINDOW) {
-                discard_older_events(&rule->produced, window_cutoff);
-            }
-
-            // now check for minimality and remove anything that isn't
+            // skip this work if not testing for minimality
             if (!opt_full) {
+                // before testing minimality, if a window is used, remove anything from the produced pool that is too old
+                if (opt_window_size != NO_WINDOW) {
+                    discard_older_events(&rule->produced, window_cutoff);
+                }
+
+                // now check for minimality and remove anything that isn't
                 select_minimal(&rule->new_intervals, &rule->produced);
             }
             // finally add anything left to the produced pool, and to the output if the rule isn't hidden
@@ -640,7 +641,10 @@ void add_interval_to_specification(nfer_specification *spec, interval *add, pool
                 /* set the hidden flag */
                 accepted->hidden = rule->hidden;
 
-                add_interval(&rule->produced, accepted);
+                // skip adding to the produced pool if not using minimality
+                if (!opt_full) {
+                    add_interval(&rule->produced, accepted);
+                }
                 add_interval(out, accepted);
             }
 
@@ -703,15 +707,17 @@ void add_interval_to_specification(nfer_specification *spec, interval *add, pool
                     }
                 } // for left_cache
 
-                // before testing minimality, if a window is used, remove anything from the produced pool that is too old
-                if (opt_window_size != NO_WINDOW) {
-                    discard_older_events(&rule->produced, window_cutoff);
-                }
-
-                // now check for minimality and remove anything that isn't
+                // skip this work if not testing for minimality
                 if (!opt_full) {
+                    // before testing minimality, if a window is used, remove anything from the produced pool that is too old
+                    if (opt_window_size != NO_WINDOW) {
+                        discard_older_events(&rule->produced, window_cutoff);
+                    }
+
+                    // now check for minimality and remove anything that isn't
                     select_minimal(&rule->new_intervals, &rule->produced);
                 }
+
                 // finally add anything left to the produced pool, and to the output if the rule isn't hidden
                 // recurse on the interval being added
                 get_pool_iterator(&rule->new_intervals, &new_pit);
@@ -720,7 +726,10 @@ void add_interval_to_specification(nfer_specification *spec, interval *add, pool
                     /* set the hidden flag */
                     accepted->hidden = rule->hidden;
 
-                    add_interval(&rule->produced, accepted);
+                    // skip adding to the produced pool if not using minimality
+                    if (!opt_full) {
+                        add_interval(&rule->produced, accepted);
+                    }
                     add_interval(out, accepted);
                 }
             }
@@ -744,7 +753,11 @@ void run_nfer(nfer_specification *spec, pool *input_pool, pool *output_pool) {
     int out_pool_index, cycle;
     interval *intv;
     pool_iterator pit;
-    pool internal_pool[2], *in, *out;
+#ifndef NO_DYNAMIC_MEMORY
+    // this is a global in the compiled monitor
+    pool internal_pool[2];
+#endif
+    pool *in, *out;
     bool converged = false;
 
     // initially, point at the input pool
@@ -752,16 +765,19 @@ void run_nfer(nfer_specification *spec, pool *input_pool, pool *output_pool) {
     out_pool_index = 0;
     cycle = 0;
 
-    filter_log_msg(LOG_LEVEL_STATUS, "Running nfer...\n");
+    filter_log_msg(LOG_LEVEL_DEBUG, "Running nfer with internal pools [%x,%x]\n", &internal_pool[0], &internal_pool[1]);
 
     while (!converged) {
         cycle++;
-        filter_log_msg(LOG_LEVEL_STATUS, "Starting cycle %d\n", cycle);
+        filter_log_msg(LOG_LEVEL_DEBUG, "Starting cycle %d\n", cycle);
 
         // set up the output pool
         out = &internal_pool[out_pool_index % 2];
         out_pool_index++;
+        #ifndef NO_DYNAMIC_MEMORY
+        // initializing a static pool is destructive
         initialize_pool(out);
+        #endif
 
         // now run the nfer spec on the intervals in the pool
         get_pool_iterator(in, &pit);
